//*****************************************************************************
//
// qtmixer - an X windows soundcard mixer program.
// Copyright (C) 1997 - 2000  Tom Daley
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The license is in the file COPYING.
//
// Tom Daley
// 1309 W. Lorraine Ave.
// Woodland Park, CO  80863-2329
//
// daley@codenet.net (Tom Daley)
// http://users.codenet.net/daley
//
//*****************************************************************************

#ifndef QTED_STEREO_SLIDER_H
#define QTED_STEREO_SLIDER_H

#include  <qlabel.h>
#include  "slider.h"

//*****************************************************************************
//
// This is a slider that can be changed from two sliders to one slider by  
// clicking the right mouse button.  
// The output values range from 0 (bottom) to 100 (top).
// The slider can also be set to mono mode so it can't be changed to a double
// slider.
//
//*****************************************************************************

class QtedStereoSlider : public QWidget {
   Q_OBJECT
   private:
      int _mono;
      int _locked;
      QtedSlider *_left_p, *_right_p;
   public:
      QtedStereoSlider(int left = 0, int right = 0, 
                       QWidget *parent = 0, const char *name = 0); 
      void setMono(int flag);
      int mono(void);
      int leftValue(void);
      void setLeftValue(int val);
      int rightValue(void);
      void setRightValue(int val);
      int locked(void);		// stereo sliders locked into one slider
   protected:
      void resizeEvent(QResizeEvent *);
   private slots:
      void rightPressed();		// right mouse button pressed
      void setRawLockedValue(int);	// setValue of sliders in raw form 
					// 100 = bottom, 0 = top
   signals:
      void valueChanged();		// slider value changed
};

#endif

//*****************************************************************************
